@@ -33,10 +33,29 @@ sprites["Bronann"] = {
         sleeping = "img/sprites/map/characters/bronann_dead.lua",
         kneeling = "img/sprites/map/characters/bronann_kneeling.lua",
         kneeling_left = "img/sprites/map/characters/bronann_kneeling_left.lua",
-        jump_south = "img/sprites/map/characters/bronann_jump_south.lua"
+        jump_south = "img/sprites/map/characters/bronann_jump_south.lua",
+        attack_south = "img/sprites/map/characters/bronann_attack_south.lua",
+        laughing = "img/sprites/map/characters/bronann_laughing_unarmed.lua"
     }
 }
 
+-- Overworld sprite
+sprites["Mini_Bronann"] = {
+    name = vt_system.Translate("Bronann"),
+    coll_half_width = 0.47,
+    coll_height = 0.5,
+    img_half_width = 0.5,
+    img_height = 2.0,
+    movement_speed = NORMAL_SPEED,
+    face_portrait = "img/portraits/bronann.png",
+
+    -- using special animation files.
+    standard_animations = {
+        idle = "img/sprites/map/characters/bronann_idle_overworld_unarmed.lua",
+        walk = "img/sprites/map/characters/bronann_walk_overworld_unarmed.lua"
+    },
+}
+
 sprites["Kalya"] = {
     name = vt_system.Translate("Kalya"),
     coll_half_width = 0.95,
@@ -57,7 +76,10 @@ sprites["Kalya"] = {
     custom_animations = {
         kneeling = "img/sprites/map/characters/kalya_kneeling.lua",
         struggling = "img/sprites/map/characters/kalya_struggling.lua",
-        jump_south = "img/sprites/map/characters/kalya_jump_south.lua"
+        jump_south = "img/sprites/map/characters/kalya_jump_south.lua",
+        laughing = "img/sprites/map/characters/kalya_laughing.lua",
+        hurt = "img/sprites/map/characters/kalya_hurt.lua",
+        frightened_fixed = "img/sprites/map/characters/kalya_frightened_fixed.lua",
     }
 }
 
@@ -124,6 +146,12 @@ sprites["Orlinn"] = {
     standard_animations = {
         idle = "img/sprites/map/npcs/story/orlinn_idle.lua",
         walk = "img/sprites/map/npcs/story/orlinn_walk.lua"
+    },
+
+    -- using standard (one direction only) animation files.
+    custom_animations = {
+        laughing = "img/sprites/map/npcs/story/orlinn_laughing.lua",
+        frightened_fixed = "img/sprites/map/npcs/story/orlinn_frightened_fixed.lua",
     }
 }
 
@@ -323,8 +351,8 @@ sprites["Squirrel"] = {
 -- ---------
 sprites["bat"] = {
     name = vt_system.Translate("Bat"),
-    coll_half_width = 1.0,
-    coll_height = 2.0,
+    coll_half_width = 0.6,
+    coll_height = 1.6,
     img_half_width = 1.0,
     img_height = 2.0,
     movement_speed = ENEMY_SPEED,
@@ -494,7 +522,75 @@ sprites["Eyeball"] = {
     },
 }
 
+sprites["Dark Soldier on horse"] = {
+    name = vt_system.Translate("Dark Soldier"),
+    coll_half_width = 3.0,
+    coll_height = 3.2,
+    img_half_width = 3.0,
+    img_height = 6.0,
+    movement_speed = ENEMY_SPEED,
+    face_portrait = "img/portraits/npcs/dark_soldier.png",
 
+    -- using special animation files.
+    standard_animations = {
+        idle = "img/sprites/map/npcs/soldier_on_horse_idle.lua",
+        walk = "img/sprites/map/npcs/soldier_on_horse_walk.lua"
+    }
+}
+
+sprites["Beetle"] = {
+    name = vt_system.Translate("Beetle"),
+    coll_half_width = 0.6,
+    coll_height = 1.2,
+    img_half_width = 1.25,
+    img_height = 2.6,
+    movement_speed = ENEMY_SPEED,
+    --face_portrait = "",
+
+    -- using special animation files.
+    standard_animations = {
+        idle = "img/sprites/map/enemies/beetle_idle.lua",
+        walk = "img/sprites/map/enemies/beetle_walk.lua"
+    },
+}
+
+sprites["Skeleton"] = {
+    name = vt_system.Translate("Skeleton"),
+    coll_half_width = 0.6,
+    coll_height = 1.2,
+    img_half_width = 2.0,
+    img_height = 4.0,
+    movement_speed = ENEMY_SPEED,
+    --face_portrait = "",
+
+    -- using special animation files.
+    standard_animations = {
+        idle = "img/sprites/map/enemies/skeleton_idle.lua",
+        walk = "img/sprites/map/enemies/skeleton_walk.lua"
+    },
+}
+
+sprites["Andromalius"] = {
+    name = vt_system.Translate("Andromalius"),
+    coll_half_width = 1.781,
+    coll_height = 3.0,
+    img_half_width = 1.781,
+    img_height = 5.5,
+    movement_speed = ENEMY_SPEED,
+    --face_portrait = "",
+
+    -- using special animation files.
+    standard_animations = {
+        idle = "img/sprites/map/enemies/andromalius_idle.lua",
+        walk = "img/sprites/map/enemies/andromalius_idle.lua"
+    },
+
+    -- using standard (one direction only) animation files.
+    custom_animations = {
+        open_mouth_right = "img/sprites/map/enemies/andromalius_openmouth_right.lua",
+        open_mouth_left = "img/sprites/map/enemies/andromalius_openmouth_left.lua",
+    }
+}
 
 function CreateSprite(Map, name, x, y)
     if (sprites[name] == nil) then
