@@ -16,24 +16,23 @@ end
 -- Character IDs. Each ID can have only a single bit active as IDs are used in bitmask operations.
 BRONANN  = 1;
 KALYA    = 2;
-THANIS   = 4;
-SYLVE    = 8;
+SYLVE    = 4;
+THANIS   = 8;
+
+-- level cap
+GlobalManager:SetMaxExperienceLevel(30);
 
 function NewGame()
     -- Prepare the new game data
     GlobalManager:AddCharacter(BRONANN);
     GlobalManager:SetDrunes(0);
 
-    -- level cap
-    -- Set to lvl 15 as there is only one dungeon.
-    GlobalManager:SetMaxExperienceLevel(15);
-
     -- Set the starting world map data
-    GlobalManager:SetWorldMap("img/menus/worldmaps/test_map.png")
+    GlobalManager:SetWorldMap("img/menus/worldmaps/layna_region.png")
     GlobalManager:ShowWorldLocation("layna village")
     GlobalManager:SetCurrentLocationId("layna village")
 
-    local MM = hoa_map.MapMode("dat/maps/introduction.lua");
+    local MM = vt_map.MapMode("dat/maps/layna_forest/layna_forest_crystal_map.lua", "dat/maps/introduction.lua");
     ModeManager:Pop(false, false);
     ModeManager:Push(MM, false, true);
 end
