@@ -46,7 +46,7 @@ function Load(m)
     _CreateZones();
 
     -- Add clouds overlay
-    Map:GetEffectSupervisor():EnableAmbientOverlay("img/ambient/clouds.png", 5.0, 5.0, true);
+    Map:GetEffectSupervisor():EnableAmbientOverlay("img/ambient/clouds.png", 5.0, -5.0, true);
 
     _HandleTwilight();
 end
@@ -713,7 +713,7 @@ function _CreateEnemies()
     _SetBattleEnvironment(enemy);
     enemy:NewEnemyParty();
     enemy:AddEnemy(1);
-    enemy:AddEnemy(1);
+    enemy:AddEnemy(2);
     enemy:AddEnemy(1);
     enemy:NewEnemyParty();
     enemy:AddEnemy(1);
