@@ -42,7 +42,7 @@ function Load(m)
     _CreateEvents();
 
     -- Add clouds overlay
-    Map:GetEffectSupervisor():EnableAmbientOverlay("img/ambient/clouds.png", 5.0, 5.0, true);
+    Map:GetEffectSupervisor():EnableAmbientOverlay("img/ambient/clouds.png", 5.0, -5.0, true);
 
     -- Put last to get a proper night effect
     Map:GetScriptSupervisor():AddScript("dat/maps/common/at_night.lua");
@@ -326,7 +326,7 @@ function _CreateEvents()
     dialogue = vt_map.SpriteDialogue();
     text = vt_system.Translate("There must be soldiers everywere, we're never gonna make it...");
     dialogue:AddLine(text, bronann);
-    text = vt_system.Translate("Stop worrying. We also have our little secrets...");
+    text = vt_system.Translate("This town has many secrets...");
     dialogue:AddLineEvent(text, kalya, "", "Kalya looks at Orlinn");
     text = vt_system.Translate("You can go in there, Orlinn.");
     dialogue:AddLine(text, kalya);
@@ -334,7 +334,7 @@ function _CreateEvents()
     dialogue:AddLineEvent(text, orlinn, "", "Orlinn goes into the secret passage");
     text = vt_system.Translate("See?");
     dialogue:AddLineEvent(text, kalya, "Kalya looks east", "");
-    text = vt_system.Translate("... I understand now why Grandma actually never saw you using the 'normal' path...");
+    text = vt_system.Translate("... I understand why Grandma actually never saw you using the 'normal' path...");
     dialogue:AddLineEmote(text, bronann, "thinking dots");
     text = vt_system.Translate("Now come...");
     dialogue:AddLine(text, kalya);
