@@ -46,7 +46,7 @@ function Load(m)
     _CreateZones();
 
     -- Add clouds overlay
-    Map:GetEffectSupervisor():EnableAmbientOverlay("img/ambient/clouds.png", 5.0, 5.0, true);
+    Map:GetEffectSupervisor():EnableAmbientOverlay("img/ambient/clouds.png", 5.0, -5.0, true);
 
     _HandleCredits();
 
@@ -142,7 +142,7 @@ function _CreateObjects()
     -- Add hill treasure chest
     local hill_chest = CreateTreasure(Map, "riverbank_secret_hill_chest", "Wood_Chest1", 72, 5);
     if (hill_chest ~= nil) then
-        hill_chest:AddObject(1, 1);
+        hill_chest:AddObject(1, 3); -- 3 small potions
         Map:AddGroundObject(hill_chest);
     end
 
@@ -242,6 +242,9 @@ function _CreateEvents()
                                        "dat/maps/layna_village/layna_village_center_script.lua", "from_secret_path");
     EventManager:RegisterEvent(event);
 
+    event = vt_map.ScriptedEvent("Orlinn laughs", "orlinn_laughs", "");
+    EventManager:RegisterEvent(event);
+
     -- Quest events - Hide and seek 2
     dialogue = vt_map.SpriteDialogue();
     text = vt_system.Translate("Wow! You found me!");
@@ -340,7 +343,7 @@ function _CreateEvents()
     EventManager:RegisterEvent(event);
 
     dialogue = vt_map.SpriteDialogue();
-    text = vt_system.Translate("Orlinn! How many times did I tell you not to bother other people?");
+    text = vt_system.Translate("Orlinn! How many times have I told you not to bother other people?");
     dialogue:AddLine(text, kalya);
     text = vt_system.Translate("But sis! I...");
     dialogue:AddLineEmote(text, orlinn, "sweat drop");
@@ -392,6 +395,7 @@ function _CreateEvents()
 
     event = vt_map.TreasureEvent("Quest1: Hide and Seek3: Orlinn gives the pen to Bronann");
     event:AddObject(70001, 1); -- The ink key item
+    event:SetDrunes(50); -- The reward for running after Orlinn for so long.
     event:AddEventLinkAtEnd("Quest1: Hide and Seek3: Orlinn is going away for real");
     event:AddEventLinkAtEnd("Quest1: Hide and Seek3: Lilly tells Bronann a bit about Kalya", 2000);
     EventManager:RegisterEvent(event);
@@ -486,7 +490,7 @@ function _CreateEvents()
     dialogue = vt_map.SpriteDialogue();
     text = vt_system.Translate("Thanks, Lilly.");
     dialogue:AddLine(text, bronann);
-    text = vt_system.Translate("We're having a shortage of food lately. And I've been taking... special measures to make sure that everyone has enough food.");
+    text = vt_system.Translate("We've been having a shortage of food lately. I've been taking... special measures... to ensure that everyone has enough food.");
     dialogue:AddLine(text, lilly);
     text = vt_system.Translate("Try to enjoy this day, Bronann.");
     dialogue:AddLine(text, lilly);
@@ -622,7 +626,7 @@ function _SetOrlinnState()
         return;
     elseif (GlobalManager:DoesEventExist("layna_riverbank", "quest1_orlinn_hide_n_seek2_done") == true) then
         orlinn:SetPosition(74, 44);
-    orlinn:SetDirection(vt_map.MapMode.WEST);
+        orlinn:SetDirection(vt_map.MapMode.WEST);
 
         -- Final hide and seek dialogue
         dialogue = vt_map.SpriteDialogue();
@@ -637,11 +641,11 @@ function _SetOrlinnState()
         -- Orlinn is on the cliff and is mocking Bronann.
         dialogue = vt_map.SpriteDialogue();
         text = vt_system.Translate("Hee hee hee!");
-        dialogue:AddLine(text, orlinn_dialogue_npc);
+        dialogue:AddLineEvent(text, orlinn_dialogue_npc, "Orlinn laughs", "");
         text = vt_system.Translate("Orlinn, how did you get there?");
         dialogue:AddLine(text, bronann);
         text = vt_system.Translate("(giggle) I won't tell you!");
-        dialogue:AddLine(text, orlinn_dialogue_npc);
+        dialogue:AddLineEvent(text, orlinn_dialogue_npc, "Orlinn laughs", "");
         DialogueManager:AddDialogue(dialogue);
         orlinn_dialogue_npc:AddDialogueReference(dialogue);
         return;
@@ -665,6 +669,10 @@ map_functions = {
         end
     end,
 
+    orlinn_laughs = function()
+        orlinn:SetCustomAnimation("laughing", 1000);
+    end,
+
     Prepare_orlinn_kalya_scene = function()
         Map:PushState(vt_map.MapMode.STATE_SCENE);
         -- Prepare Kalya
